#ifndef NT2_INCLUDE_FUNCTIONS_CHEBVAND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CHEBVAND_HPP_INCLUDED

#include <nt2/gallery/include/functions/chebvand.hpp>

#endif
